
.. blogpost::
    :title: Module sphinxcontrib.blockdiag
    :keywords: blockdiag, sphinx
    :date: 2017-07-02
    :categories: sphinx

    `sphinxcontrib.blockdiag <https://pypi.python.org/pypi/sphinxcontrib-blockdiag>`_
    provides an elegant way to build graph in a Sphinx documentation.
    See the `examples <http://blockdiag.com/en/blockdiag/examples.html#label-attributes-to-nodes-and-edges>`_.
